@@ -19,16 +19,12 @@ sub ip_address {
 }
 
 sub utf8_string {
-    return 'déjà vu';
-}
-
-sub utf8_decoded_string {
     my $string = "déjà vu";
     utf8::decode($string);
     return $string;
 }
 
 
-__PACKAGE__->register_rpc_method_names( 'utf8_decoded_string', 'utf8_string', 'sum', { name => 'ip_address', options => { with_plack_request => 1 }} );
+__PACKAGE__->register_rpc_method_names( 'utf8_string', 'sum', { name => 'ip_address', options => { with_plack_request => 1 }} );
 
 1;
