@@ -1,12 +1,12 @@
 package JSON::RPC::Dispatcher;
-$JSON::RPC::Dispatcher::VERSION = '0.0507';
+$JSON::RPC::Dispatcher::VERSION = '0.0508';
 =head1 NAME
 
 JSON::RPC::Dispatcher - A JSON-RPC 2.0 server.
 
 =head1 VERSION
 
-version 0.0507
+version 0.0508
 
 =head1 SYNOPSIS
 
@@ -50,6 +50,9 @@ This module follows the draft specficiation for JSON-RPC 2.0. More information c
 
 =head2 Registration Options
 
+The C<register> method cannot be used to register methods that start with m/^rpc\./.  Per the JSON-RPC 2.0 specification, these are reserved for 
+rpc-internal extensions.
+
 The C<register> method takes a third argument which is a hash reference of named options that effects how the code should be handled.
 
 =head3 with_plack_request
@@ -196,6 +199,13 @@ sub clear_error {
 #--------------------------------------------------------
 sub register {
     my ($self, $name, $sub, $options) = @_;
+
+	if(defined($name) && $name =~ m{^rpc\.}) { 
+		die "$name is an invalid name for a method. (Methods matching m/^rpc\\./ are reserved for rpc-internal procedures)";
+	} elsif(!defined($name) || $name eq '' || ref($name)) {
+		die "Registered method name must be a defined non-empty string and not start with 'rpc.'";	
+	}
+ 
     my $rpcs = $self->rpcs;
     $rpcs->{$name} = {
         function            => $sub,
@@ -337,12 +347,12 @@ sub handle_procedures {
                 }
                 elsif ($@) {
                     my $error = $@;
-                    if ($error->can('error') && $error->can('trace')) {
+                    if (blessed($error) && $error->can('error') && $error->can('trace')) {
                          $log->fatal($error->error);
                          $log->trace($error->trace->as_string);
                          $error = $error->error;
                     }
-                    elsif ($error->can('error')) {
+                    elsif (blessed($error) && $error->can('error')) {
                         $error = $error->error;
                         $log->fatal($error);
                     }
